EmojiPanel class

Inheritance

Constructors

EmojiPanel({Key? key, required void onTapEmoji(int unicode), required void onSubmitted(), required void delete(), bool showBottomContainer = true})

Properties

delete → void Function()
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSubmitted → void Function()
final
onTapEmoji → void Function(int unicode)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBottomContainer bool
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
isAndroidDevice() bool
inherited
isIosDevice() bool
inherited
isWebDevice() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTIMCallback(TIMCallback callbackValue) → void
inherited
timBuild(BuildContext context) Widget
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
tuiBuild(BuildContext context, TUIKitBuildValue value) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited